<?php

namespace SupplyTek\Utilities;

/**
 * Manipulates PHP Session
 * 
 * Class to handle data from PHP Session, like Get/Set and clear Session values.
 * 
 * @author Rômulo Alves Lousada
 */
class SessionHandler
{
    /**
     * Class constructor
     * 
     * If the session is not started yet, start it to be able to manipulate the
     * data stored in it.
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function __construct()
    {
        if (session_status() == PHP_SESSION_NONE) {
            session_start();
        }
    }

    /**
     * Returns Session stored value of the path sent
     * 
     * Check the session searching for the path and variable sent and
     * return the desired data requested.
     * 
     * @param string $variable Index name of value.
     * @param string $path (optional) Path to the index.
     * 
     * @return string
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function getSessionData($variable, $path = "user_data")
    {
        if (isset($_SESSION[$path][$variable])) {
            return $_SESSION[$path][$variable];
        }

        return false;
    }

    /**
     * Sets Session value of the path sent
     * 
     * Attempt to set a data in the session with some restrictions
     * Does not set anything if the data tries to overwrite something.
     * 
     * @param string $variable Index name of value
     * @param string $value Value to be stored
     * @param string $path (optional) Path to the index
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function setSessionData($variable, $value, $path = "user_data")
    {
        if (!isset($_SESSION[$path])) {
            $_SESSION[$path] = array();
        }
        
        $_SESSION[$path][$variable] = $value;
    }

    /**
     * Clears Session variable specified
     * 
     * Searchs a session variable in path sent and attempts to remove it,
     * but will not remove any variable from important paths that
     * where setted with login data.
     * 
     * @author Rômulo Alves Lousada
     * 
     * @param string $variable Index name of value
     * @param string $path Path to the index
     * 
     * @return string (on Error)
     */
    public function clearSessionVariable($variable, $path)
    {
        if ($path != "user_data" && $path != "param_geral_data") {
            if (isset($_SESSION[$path][$variable])) {
                unset($_SESSION[$path][$variable]);
            } else {
                return "Couldn't find '" . $variable . "' in '" . $path . "'";
            } 
        } else {
            return "Can't clear the path '" . $path . "' due to security reasons.";
        }
    }

    /**
     * Clear all Session variables
     * 
     * Removes all data from the session, usually called to redirect
     * the current user to the login page.
     * 
     * @return void
     * 
     * @author Rômulo Alves Lousada
     */
    public function clearSession()
    {
        session_unset();
    }

    /**
     * Echo all the variables in Session.
     * 
     * Function created to print on screen all the data that
     * is stored on the session, so the developer can see and search
     * for a value and check it's path.
     * 
     * @return void
     * 
     * @author Rômulo Alves Lousada
     */
    public function checkSession()
    {
        echo '<pre>'.print_r($_SESSION, true).'</pre>';
    }
}